@@ -1068,21 +1068,24 @@ class TestUtilSSL:
         warn.assert_not_called()
 
     @pytest.mark.parametrize(
-        "openssl_version_number, implementation_name, version_info, reliable",
+        "openssl_version, openssl_version_number, implementation_name, version_info, reliable",
         [
             # OpenSSL and Python OK -> reliable
-            (0x101010CF, "cpython", (3, 9, 3), True),
+            ("OpenSSL 1.1.1", 0x101010CF, "cpython", (3, 9, 3), True),
             # Python OK -> reliable
-            (0x10101000, "cpython", (3, 9, 3), True),
-            (0x10101000, "pypy", (3, 6, 9), False),
+            ("OpenSSL 1.1.1", 0x10101000, "cpython", (3, 9, 3), True),
+            ("OpenSSL 1.1.1", 0x10101000, "pypy", (3, 6, 9), False),
             # OpenSSL OK -> reliable
-            (0x101010CF, "cpython", (3, 9, 2), True),
-            # unreliable
-            (0x10101000, "cpython", (3, 9, 2), False),
+            ("OpenSSL 1.1.1", 0x101010CF, "cpython", (3, 9, 2), True),
+            # not OpenSSSL -> unreliable
+            ("LibreSSL 2.8.3", 0x101010CF, "cpython", (3, 10, 0), False),
+            # old OpenSSL and old Python, unreliable
+            ("OpenSSL 1.1.0", 0x10101000, "cpython", (3, 9, 2), False),
         ],
     )
     def test_is_has_never_check_common_name_reliable(
         self,
+        openssl_version: str,
         openssl_version_number: int,
         implementation_name: str,
         version_info: _TYPE_VERSION_INFO,
@@ -1090,6 +1093,7 @@ class TestUtilSSL:
     ) -> None:
         assert (
             _is_has_never_check_common_name_reliable(
+                openssl_version,
                 openssl_version_number,
                 implementation_name,
                 version_info,
